#Bibliotecas necessárias
library(readxl)
library(caret)
library(esquisse)
library(bbmle)
library(diptest)
library(goft)

#Importar o banco de dados 
database <- read_excel("Banco de dados", sheet = "Planilha")
View(database)

#Criação do correlalograma
corrgram(database, lower.panel=panel.pts, upper.panel=panel.conf,
         diag.panel=panel.density)

#Abrir plataforma esquisse
esquisse::esquisser()

#Definir a variável de análise 
vari <- (database$"Variável de desejo")

#Tetes de distribuições
fitW <- fitdist(vari, "weibull")
fitg <- fitdist(vari, "gamma")
fitln <- fitdist(vari, "lnorm")
fitn <-fitdist(vari,"norm")
fite <-fitdist(vari,"exp")
summary(fitW)
summary(fitg)
summary(fitln)
summary(fitn)
summary(fite)
cdfcomp(list(fitW, fitg, fitln, fitn, fite), legendtext=c("Weibull", "gamma", "lognormal","normal","exponencial"))
denscomp(list(fitW, fitg, fitln, fitn, fite), legendtext=c("Weibull", "gamma", "lognormal","normal","exponencial"))
qqcomp(list(fitW, fitg, fitln, fitn, fite), legendtext=c("Weibull", "gamma", "lognormal","normal","exponencial"))
ppcomp(list(fitW, fitg, fitln, fitn, fite), legendtext=c("Weibull", "gamma", "lognormal","normal","exponencial"))
gofstat(list(fitW, fitg, fitln, fitn, fite), fitnames=c("Weibull", "gamma", "lognormal","normal","exponencial"))


#Testes de distribuição caso não seja possível definir a exponencial
fitW <- fitdist(vari, "weibull")
fitg <- fitdist(vari, "gamma")
fitln <- fitdist(vari, "lnorm")
fitn <-fitdist(vari,"norm")
summary(fitW)
summary(fitg)
summary(fitln)
summary(fitn)
cdfcomp(list(fitW, fitg, fitln, fitn), legendtext=c("Weibull", "gamma", "lognormal","normal"))
denscomp(list(fitW, fitg, fitln, fitn), legendtext=c("Weibull", "gamma", "lognormal","normal"))
qqcomp(list(fitW, fitg, fitln, fitn), legendtext=c("Weibull", "gamma", "lognormal","normal"))
ppcomp(list(fitW, fitg, fitln, fitn), legendtext=c("Weibull", "gamma", "lognormal","normal"))
gofstat(list(fitW, fitg, fitln, fitn), fitnames=c("Weibull", "gamma", "lognormal","normal"))


#Testes de distribuição caso aó aeja possível testar exponencial e normal
fitn <-fitdist(vari,"norm")
fite <-fitdist(vari,"exp")
summary(fitn)
summary(fite)
cdfcomp(list(fitn, fite), legendtext=c("normal","exponencial"))
denscomp(list(fitn, fite), legendtext=c("normal","exponencial"))
qqcomp(list(fitn, fite), legendtext=c("normal","exponencial"))
ppcomp(list( fitn, fite), legendtext=c("normal","exponencial"))
gofstat(list( fitn, fite), fitnames=c("normal","exponencial"))

#Teste de modalidades
dip.test(vari)
is.amodal(vari)
is.unimodal(vari)
is.bimodal(vari)
is.trimodal(vari)
is.iterquad(vari)
bimodality_coefficient(vari)
